==> junit-quickcheck-generators-0.9.4-sources.jar: com/pholser/junit/quickcheck/generator/VoidGenerator.java <==
/*
 The MIT License

 Copyright (c) 2010-2020 Paul R. Holser, Jr.

 Permission is hereby granted, free of charge, to any person obtaining
 a copy of this software and associated documentation files (the
 "Software"), to deal in the Software without restriction, including
 without limitation the rights to use, copy, modify, merge, publish,
 distribute, sublicense, and/or sell copies of the Software, and to
 permit persons to whom the Software is furnished to do so, subject to
 the following conditions:

 The above copyright notice and this permission notice shall be
 included in all copies or substantial portions of the Software.

 THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND,
 EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF
 MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND
 NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE
 LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION
 OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION
 WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
*/

package com.pholser.junit.quickcheck.generator;

import com.pholser.junit.quickcheck.random.SourceOfRandomness;

import static java.util.Arrays.*;

/**
 * Produces values for property parameters of type {@code void} or
 * {@link Void}.
 */
public class VoidGenerator extends Generator<Void> {
    @SuppressWarnings("unchecked") public VoidGenerator() {
        super(asList(Void.class, void.class));
    }

    @Override public Void generate(SourceOfRandomness random, GenerationStatus status) {
        return null;
    }

    @Override
    public boolean canRegisterAsType(Class<?> type) {
        return !Object.class.equals(type);
    }
}

==> junit-quickcheck-generators-1.0-sources.jar: com/pholser/junit/quickcheck/generator/VoidGenerator.java <==
/*
 The MIT License

 Copyright (c) 2010-2020 Paul R. Holser, Jr.

 Permission is hereby granted, free of charge, to any person obtaining
 a copy of this software and associated documentation files (the
 "Software"), to deal in the Software without restriction, including
 without limitation the rights to use, copy, modify, merge, publish,
 distribute, sublicense, and/or sell copies of the Software, and to
 permit persons to whom the Software is furnished to do so, subject to
 the following conditions:

 The above copyright notice and this permission notice shall be
 included in all copies or substantial portions of the Software.

 THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND,
 EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF
 MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND
 NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE
 LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION
 OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION
 WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
*/

package com.pholser.junit.quickcheck.generator;

import static java.util.Arrays.asList;

import com.pholser.junit.quickcheck.random.SourceOfRandomness;

/**
 * Produces values for property parameters of type {@code void} or
 * {@link Void}.
 */
public class VoidGenerator extends Generator<Void> {
    public VoidGenerator() {
        super(asList(Void.class, void.class));
    }

    @Override public Void generate(
        SourceOfRandomness random,
        GenerationStatus status) {

        return null;
    }

    @Override
    public boolean canRegisterAsType(Class<?> type) {
        return !Object.class.equals(type);
    }
}
